@@ -20,7 +20,13 @@ class Instances(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-ens.datasource.Instances",
 ):
-    '''A ROS resource type:  ``DATASOURCE::ENS::Instances``.'''
+    '''This class encapsulates and extends the ROS resource type ``DATASOURCE::ENS::Instances``, which is used to query the details of Edge Node Service (ENS) instances.
+
+    :Note:
+
+    This class may have some new functions to facilitate development, so it is recommended to use this class instead of ``RosInstances``for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/datasource-ens-instances
+    '''
 
     def __init__(
         self,
@@ -29,11 +35,7 @@ class Instances(
         props: typing.Optional[typing.Union["InstancesProps", typing.Dict[builtins.str, typing.Any]]] = None,
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''Create a new ``DATASOURCE::ENS::Instances``.
-
-        Param scope - scope in which this resource is defined
-        Param id    - scoped id of the resource
-        Param props - resource properties
+        '''Param scope - scope in which this resource is defined Param id    - scoped id of the resource Param props - resource properties.
 
         :param scope: -
         :param id: -
@@ -60,6 +62,54 @@ class Instances(
         '''Attribute Instances: The list of instances.'''
         return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrInstances"))
 
+    @builtins.property
+    @jsii.member(jsii_name="enableResourcePropertyConstraint")
+    def _enable_resource_property_constraint(self) -> builtins.bool:
+        return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
+
+    @_enable_resource_property_constraint.setter
+    def _enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__27d08b3eb56f12dbfff04f81d188ddb6f614c097e2375d87d3f80e7fe3f3e9d1)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "enableResourcePropertyConstraint", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="id")
+    def _id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "id"))
+
+    @_id.setter
+    def _id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__691a4353858d14c91639bd3286178a4a56a7a78454a6c19fa5926de0d7fec3eb)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "id", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def _props(self) -> "InstancesProps":
+        return typing.cast("InstancesProps", jsii.get(self, "props"))
+
+    @_props.setter
+    def _props(self, value: "InstancesProps") -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__17fb4d49239082e21c222d61e3f94b4ed38e7eb2cfcd99e9568df803a3412808)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "props", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="scope")
+    def _scope(self) -> _ros_cdk_core_7adfd82f.Construct:
+        return typing.cast(_ros_cdk_core_7adfd82f.Construct, jsii.get(self, "scope"))
+
+    @_scope.setter
+    def _scope(self, value: _ros_cdk_core_7adfd82f.Construct) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__37d1be41c19ea379dd113719829174f7eb9cf286174ca735d95d2eddc8a75d7e)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "scope", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-ens.datasource.InstancesProps",
@@ -71,6 +121,7 @@ class Instances(
         "instance_ids": "instanceIds",
         "instance_name": "instanceName",
         "instance_resource_type": "instanceResourceType",
+        "refresh_options": "refreshOptions",
         "status": "status",
     },
 )
@@ -84,9 +135,12 @@ class InstancesProps:
         instance_ids: typing.Optional[typing.Union[typing.Sequence[typing.Any], _ros_cdk_core_7adfd82f.IResolvable]] = None,
         instance_name: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         instance_resource_type: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         status: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``DATASOURCE::ENS::Instances``.
+        '''Properties for defining a ``Instances``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/datasource-ens-instances
 
         :param ens_region_ids: Property ensRegionIds: The list of ENS region IDs.
         :param ens_service_id: Property ensServiceId: The ID of ENS service.
@@ -94,6 +148,7 @@ class InstancesProps:
         :param instance_ids: Property instanceIds: The list of instance IDs.
         :param instance_name: Property instanceName: The name of instance.
         :param instance_resource_type: Property instanceResourceType: The resource type of instance. Valid values: EnsPostPaidInstance: PostPaid instance. EnsService: Edge service instance. BuildMachine: Image building machine.
+        :param refresh_options: Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values: - Never: Never refresh the datasource resource when the stack is updated. - Always: Always refresh the datasource resource when the stack is updated. Default is Never.
         :param status: Property status: The status of instance.
         '''
         if __debug__:
@@ -104,6 +159,7 @@ class InstancesProps:
             check_type(argname="argument instance_ids", value=instance_ids, expected_type=type_hints["instance_ids"])
             check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
             check_type(argname="argument instance_resource_type", value=instance_resource_type, expected_type=type_hints["instance_resource_type"])
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if ens_region_ids is not None:
@@ -118,6 +174,8 @@ class InstancesProps:
             self._values["instance_name"] = instance_name
         if instance_resource_type is not None:
             self._values["instance_resource_type"] = instance_resource_type
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
         if status is not None:
             self._values["status"] = status
 
@@ -175,6 +233,21 @@ class InstancesProps:
         result = self._values.get("instance_resource_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated.
+
+        Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+          Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     @builtins.property
     def status(
         self,
@@ -200,7 +273,13 @@ class RosInstances(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-ens.datasource.RosInstances",
 ):
-    '''A ROS template type:  ``DATASOURCE::ENS::Instances``.'''
+    '''This class is a base encapsulation around the ROS resource type ``DATASOURCE::ENS::Instances``, which is used to query the details of Edge Node Service (ENS) instances.
+
+    :Note:
+
+    This class does not contain additional functions, so it is recommended to use the ``Instances`` class instead of this class for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/datasource-ens-instances
+    '''
 
     def __init__(
         self,
@@ -209,8 +288,7 @@ class RosInstances(
         props: typing.Union["RosInstancesProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
-        '''Create a new ``DATASOURCE::ENS::Instances``.
-
+        '''
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param props: - resource properties.
@@ -401,6 +479,32 @@ class RosInstances(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceResourceType", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="refreshOptions")
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], jsii.get(self, "refreshOptions"))
+
+    @refresh_options.setter
+    def refresh_options(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c9cb0b39bd386568c5e788959ed3c3e15571976655a73f375d226990c4f10dc9)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "refreshOptions", value)
+
     @builtins.property
     @jsii.member(jsii_name="status")
     def status(
@@ -432,6 +536,7 @@ class RosInstances(
         "instance_ids": "instanceIds",
         "instance_name": "instanceName",
         "instance_resource_type": "instanceResourceType",
+        "refresh_options": "refreshOptions",
         "status": "status",
     },
 )
@@ -445,9 +550,12 @@ class RosInstancesProps:
         instance_ids: typing.Optional[typing.Union[typing.Sequence[typing.Any], _ros_cdk_core_7adfd82f.IResolvable]] = None,
         instance_name: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         instance_resource_type: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         status: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``DATASOURCE::ENS::Instances``.
+        '''Properties for defining a ``RosInstances``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/datasource-ens-instances
 
         :param ens_region_ids: 
         :param ens_service_id: 
@@ -455,6 +563,7 @@ class RosInstancesProps:
         :param instance_ids: 
         :param instance_name: 
         :param instance_resource_type: 
+        :param refresh_options: 
         :param status: 
         '''
         if __debug__:
@@ -465,6 +574,7 @@ class RosInstancesProps:
             check_type(argname="argument instance_ids", value=instance_ids, expected_type=type_hints["instance_ids"])
             check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
             check_type(argname="argument instance_resource_type", value=instance_resource_type, expected_type=type_hints["instance_resource_type"])
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if ens_region_ids is not None:
@@ -479,6 +589,8 @@ class RosInstancesProps:
             self._values["instance_name"] = instance_name
         if instance_resource_type is not None:
             self._values["instance_resource_type"] = instance_resource_type
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
         if status is not None:
             self._values["status"] = status
 
@@ -547,6 +659,22 @@ class RosInstancesProps:
         result = self._values.get("instance_resource_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     @builtins.property
     def status(
         self,
@@ -587,6 +715,30 @@ def _typecheckingstub__3125f296d9b3d00f11100c88542575a8db85387457cc503b4215b11d5
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__27d08b3eb56f12dbfff04f81d188ddb6f614c097e2375d87d3f80e7fe3f3e9d1(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__691a4353858d14c91639bd3286178a4a56a7a78454a6c19fa5926de0d7fec3eb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17fb4d49239082e21c222d61e3f94b4ed38e7eb2cfcd99e9568df803a3412808(
+    value: InstancesProps,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37d1be41c19ea379dd113719829174f7eb9cf286174ca735d95d2eddc8a75d7e(
+    value: _ros_cdk_core_7adfd82f.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__a8219c6c0f7d9d053a2654de01527696f0ca3f56e1a14592a89d32e6193c93fe(
     *,
     ens_region_ids: typing.Optional[typing.Union[typing.Sequence[typing.Any], _ros_cdk_core_7adfd82f.IResolvable]] = None,
@@ -595,6 +747,7 @@ def _typecheckingstub__a8219c6c0f7d9d053a2654de01527696f0ca3f56e1a14592a89d32e61
     instance_ids: typing.Optional[typing.Union[typing.Sequence[typing.Any], _ros_cdk_core_7adfd82f.IResolvable]] = None,
     instance_name: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     instance_resource_type: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     status: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -657,6 +810,12 @@ def _typecheckingstub__2aa47153f3316e9b19bf39ff14b3c21a8c95a203ca8ba986501dd128c
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__c9cb0b39bd386568c5e788959ed3c3e15571976655a73f375d226990c4f10dc9(
+    value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__cc2f29652ac4e9823e6c7daaa1835b8e9480adc2780262b034a7e92d3810e136(
     value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
 ) -> None:
@@ -671,6 +830,7 @@ def _typecheckingstub__10be13f94bc8004b85fa96c794c9053049be382074aa6c863e522e38c
     instance_ids: typing.Optional[typing.Union[typing.Sequence[typing.Any], _ros_cdk_core_7adfd82f.IResolvable]] = None,
     instance_name: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     instance_resource_type: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     status: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
